.. WorQ documentation master file, created by
   sphinx-quickstart on Mon Sep  3 10:39:05 2012.

.. include:: ../README.rst


========
Contents
========

.. toctree::
   :maxdepth: 4

   examples
   worq


==================
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


=======
License
=======

.. literalinclude:: ../LICENSE.txt
